@@ -92,6 +92,7 @@ class HardwareMachineModel(str, Enum):
     EPYC_7002 = "c5a.4xlarge"
     EPYC_7003 = "m6a.4xlarge"
     SKYLAKE_SP = "m5.2xlarge"
+    A100_40G = "a2-highgpu-1g"
 
     NANO = HardwareType.NANO.value
     XAVIER = HardwareType.XAVIER.value
@@ -99,7 +100,6 @@ class HardwareMachineModel(str, Enum):
     ORIN = HardwareType.ORIN.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
     A100_80G = HardwareType.A100_80G.value
-    A100_40G = HardwareType.A100_40G.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
     APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
@@ -210,7 +210,7 @@ class HardwareTaint(str, Enum):
     T4 = "nvidia.com/t4gpu"
     A10G = "nvidia.com/a10gpu"
     A100_80G = UNKNOWN
-    A100_40G = UNKNOWN
+    A100_40G = "nvidia.com/a100gpu40g"
     NANO = "nvidia.com/jetson-nano"
     XAVIER = "nvidia.com/jetson-xavier"
     XAVIER_AGX = "nvidia.com/jetson-xavier-agx"
@@ -235,7 +235,7 @@ class HardwareLabel(str, Enum):
     T4 = "nvidia-tesla-t4"
     A10G = "nvidia-ampere-a10"
     A100_80G = UNKNOWN
-    A100_40G = UNKNOWN
+    A100_40G = "nvidia-a100-40g"
     NANO = "nvidia-jetson-nano"
     XAVIER = "nvidia-jetson-xavier"
     XAVIER_AGX = "nvidia-jetson-xavier-agx"
@@ -418,9 +418,9 @@ class HardwareTypeLabel(str, Enum):
     SKYLAKE_SP = type_with_model(HardwareMachineModel.SKYLAKE_SP)
     T4 = type_with_model(HardwareMachineModel.T4)
     A10G = type_with_model(HardwareMachineModel.A10G)
+    A100_40G = type_with_model(HardwareMachineModel.A100_40G, "A100 40GB")
 
     A100_80G = HardwareType.A100_80G.value
-    A100_40G = HardwareType.A100_40G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
